@@ -9,7 +9,7 @@ function(object,lag.max=NULL,comp=TRUE)
 		v=(2*saux%*%gam + gam[1])/n
 	}
 	else {
-		cg=spectrum.arma(ar=object$ar,ma=object$ma,sd.innov=object$sd.innov)
+		cg=spectrum.arma(ar=-object$ar,ma=object$ma,sd.innov=object$sd.innov)
 		cgamma=function(lambda) 2*cg(lambda)*gamma(1-2*object$d)*sin(pi*object$d)
 		v=cgamma(0)*(n^(2*object$d-1))/((1+2*object$d)*object$d)	
 	}
